.. This is auto-generated from `docs/README.md`. Do not edit this file directly.

=========================================================
Some convenience functions for Cosmology-related analysis
=========================================================

:Date:   March 20, 2021

.. contents::
   :depth: 3
..

+-------------+----------------------------------------------------------------------------------+
| docs        | |Documentation Status| |image2|                                                  |
+=============+==================================================================================+
| tests       | |GitHub Actions| |Coverage Status|                                               |
|             |                                                                                  |
|             | |Codacy Code Quality Status| |Scrutinizer Status| |CodeClimate Quality Status|   |
+-------------+----------------------------------------------------------------------------------+
| package     | |Supported versions| |Supported implementations| |PyPI Wheel|                    |
|             |                                                                                  |
|             | |PyPI Package latest release| |GitHub Releases| |Development Status| |Downloads| |
|             |                                                                                  |
|             | |Commits since latest release| |License|                                         |
+-------------+----------------------------------------------------------------------------------+
| conda-forge | |Conda Recipe| |Conda Downloads| |Conda Version| |Conda Platforms|               |
+-------------+----------------------------------------------------------------------------------+

Introduction
============

Here is some convenience functions for Cosmology-related analysis.

.. |Documentation Status| image:: https://readthedocs.org/projects/python-coscon/badge/?version=latest
   :target: https://python-coscon.readthedocs.io/en/latest/?badge=latest&style=plastic
.. |image1| image:: https://github.com/ickc/python-coscon/workflows/GitHub%20Pages/badge.svg
   :target: https://ickc.github.io/python-coscon
.. |GitHub Actions| image:: https://github.com/ickc/python-coscon/workflows/Python%20package/badge.svg
.. |Coverage Status| image:: https://codecov.io/gh/ickc/python-coscon/branch/master/graphs/badge.svg?branch=master
   :target: https://codecov.io/github/ickc/python-coscon
.. |Codacy Code Quality Status| image:: https://img.shields.io/codacy/grade/078ebc537c5747f68c1d4ad3d3594bbf.svg
   :target: https://www.codacy.com/app/ickc/python-coscon
.. |Scrutinizer Status| image:: https://img.shields.io/scrutinizer/quality/g/ickc/python-coscon/master.svg
   :target: https://scrutinizer-ci.com/g/ickc/python-coscon/
.. |CodeClimate Quality Status| image:: https://codeclimate.com/github/ickc/python-coscon/badges/gpa.svg
   :target: https://codeclimate.com/github/ickc/python-coscon
.. |Supported versions| image:: https://img.shields.io/pypi/pyversions/python-coscon.svg
   :target: https://pypi.org/project/python-coscon
.. |Supported implementations| image:: https://img.shields.io/pypi/implementation/python-coscon.svg
   :target: https://pypi.org/project/python-coscon
.. |PyPI Wheel| image:: https://img.shields.io/pypi/wheel/python-coscon.svg
   :target: https://pypi.org/project/python-coscon
.. |PyPI Package latest release| image:: https://img.shields.io/pypi/v/python-coscon.svg
   :target: https://pypi.org/project/python-coscon
.. |GitHub Releases| image:: https://img.shields.io/github/tag/ickc/python-coscon.svg?label=github+release
   :target: https://github.com/ickc/python-coscon/releases
.. |Development Status| image:: https://img.shields.io/pypi/status/python-coscon.svg
   :target: https://pypi.python.org/pypi/python-coscon/
.. |Downloads| image:: https://img.shields.io/pypi/dm/python-coscon.svg
   :target: https://pypi.python.org/pypi/python-coscon/
.. |Commits since latest release| image:: https://img.shields.io/github/commits-since/ickc/python-coscon/v0.1.1.svg
   :target: https://github.com/ickc/python-coscon/compare/v0.1.1...master
.. |License| image:: https://img.shields.io/pypi/l/python-coscon.svg
.. |Conda Recipe| image:: https://img.shields.io/badge/recipe-python-coscon-green.svg
   :target: https://anaconda.org/conda-forge/python-coscon
.. |Conda Downloads| image:: https://img.shields.io/conda/dn/conda-forge/python-coscon.svg
   :target: https://anaconda.org/conda-forge/python-coscon
.. |Conda Version| image:: https://img.shields.io/conda/vn/conda-forge/python-coscon.svg
   :target: https://anaconda.org/conda-forge/python-coscon
.. |Conda Platforms| image:: https://img.shields.io/conda/pn/conda-forge/python-coscon.svg
   :target: https://anaconda.org/conda-forge/python-coscon
.. |image2| image:: https://github.com/ickc/python-coscon/workflows/GitHub%20Pages/badge.svg
   :target: https://ickc.github.io/python-coscon
